=======
History
=======

2019.02 (2019-02-07)
--------------------

* Separating sweep logic into a separate module.
* Adding FilteredCartesianSweep sweep type.
* Numerous documentation changes, including many more examples.

2019.01 (2019-01-21)
--------------------

* First release on PyPI.
